==> digikam-3.0.0-beta1.tar.bz2: digikam-3.0.0-beta1/extra/kipi-plugins/piwigoexport/kipiplugin_piwigoexport.desktop.cmake <==
[Desktop Entry]
Name=Remote Piwigo Export
Name[bg]=Изнасяне към Piwigo
Name[bs]=Udaljeni Piwigo Izvoz
Name[ca]=Exportador a Piwigo remot
Name[ca@valencia]=Remote Piwigo Export
Name[cs]=Export na vzdálené Piwigo
Name[da]=Eksport til ekstern Piwigo
Name[de]=Piwigo-Export
Name[el]=Εξαγωγή σε απομακρυσμένη Piwigo
Name[en_GB]=Remote Piwigo Export
Name[es]=Exportar a un Piwigo remoto
Name[et]=Piwigo eksport
Name[eu]=Urruneko Piwigo-ra esportatzea
Name[fr]=Module externe pour l'exportation vers Piwigo
Name[ga]=Easpórtáil go Piwigo Cianda
Name[gl]=Exportación remota a Piwigo
Name[hu]=Távoli Piwigo exportálás
Name[is]=Samstilling við Piwigo myndasöfn
Name[it]=Esportazione remota a Piwigo
Name[km]=ការ​នាំ​ចេញ​ Piwigo ​ពី​ចម្ងាយ
Name[nb]=Piwigo-eksport til nettverket
Name[nl]=Piwigo-export op afstand
Name[pl]=Eksport do zdalnego Piwigo
Name[pt]=Exportação para um Piwigo Remoto
Name[pt_BR]=Exportar para Piwigo remoto
Name[ro]=Export către Piwigo
Name[ru]=Экспорт в Piwigo
Name[sl]=Izvoz v oddaljeno storitev Piwigo
Name[sv]=Fjärrexport till Piwigo
Name[th]=ส่งออกไปยังบริการ Piwigo ทางไกล
Name[uk]=Експорт до віддаленого ресурсу Piwigo
Name[x-test]=xxRemote Piwigo Exportxx
Name[zh_CN]=远程 Piwigo 导出
Name[zh_TW]=遠端 Piwigo 匯出
Comment=A tool to export images to a remote Piwigo
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Piwigo
Comment[bs]=Alat za izvoz slika na udaljeni Piwigo
Comment[ca]=Una eina per exportar imatges al servei remot Piwigo
Comment[ca@valencia]=Una eina per exportar imatges al servei remot Piwigo
Comment[cs]=;Nástroj pro export obrázků na vzdálené Piwigo
Comment[da]=Et værktøj til at eksportere billeder til en ekstern Piwigo
Comment[de]=Ein Werkzeug, um Bilder zu einer entfernten Piwigo-Installation zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη πινακοθήκη Piwigo
Comment[en_GB]=A tool to export images to a remote Piwigo
Comment[es]=Una herramienta para exportar imágenes a un Piwigo remoto
Comment[et]=Tööriist piltide eksportimiseks Piwigosse
Comment[eu]=Urruneko Piwigo-ra irudiak esportatzeko tresna
Comment[fr]=Outil pour l'exportation vers Piwigo
Comment[gl]=Unha ferramenta para exportar imaxes a un Piwigo remoto
Comment[hu]=Egy eszköz képek exportálásához egy távoli Piwigo-ba
Comment[is]=Verkfæri til að senda myndir í fjarlæg Piwigo myndasöfn
Comment[it]=Uno strumento per esportare immagini a un Piwigo remoto
Comment[km]=ឧបករណ៍​សម្រាប់​នាំ​ចេញ​រូបភាព​ទៅ​កាន់​ Piwigo ពី​ចម្ងាយ
Comment[nb]=Et verktøy for å eksportere bilder til en fjern Piwigo
Comment[nl]=Een hulpmiddel om afbeeldingen te exporteren naar Piwigo op afstand
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnego Piwigo
Comment[pt]=Uma ferramenta para exportar imagens para um Piwigo remoto
Comment[pt_BR]=Uma ferramenta para exportar imagens para um Piwigo remoto
Comment[ro]=O unealtă de exportat imagini către Piwigo
Comment[ru]=Инструмент для экспорта изображений в Piwigo
Comment[sl]=Orodje za izvoz slik v oddaljeno storitev Piwigo
Comment[sv]=Ett verktyg för att fjärrexportera bilder till Piwigo
Comment[th]=เครื่องมือส่งออกภาพต่าง ๆ ไปยังบริการ Piwigo ทางไกล
Comment[uk]=Інструмент для експорту зображення до віддаленого ресурсу Piwigo
Comment[x-test]=xxA tool to export images to a remote Piwigoxx
Comment[zh_CN]=一个将图像导出到远程 Piwigo 的工具
Comment[zh_TW]=匯出影像到遠端 Piwigo 的工具
Type=Service
Icon=piwigo
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_piwigoexport
X-KIPI-PluginCategories=Export
author=Frederic Coiffier, fcoiffie at gmail dot com

==> digikam-3.3.0-beta1.tar.bz2: digikam-3.3.0-beta1/extra/kipi-plugins/piwigoexport/kipiplugin_piwigoexport.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Remote Piwigo Export
Name=Remote Piwigo Export
Name[bg]=Изнасяне към Piwigo
Name[bs]=Udaljeni Piwigo Izvoz
Name[ca]=Exportador a Piwigo remot
Name[ca@valencia]=Exportador a Piwigo remot
Name[cs]=Export na vzdálené Piwigo
Name[da]=Eksport til ekstern Piwigo
Name[de]=Piwigo-Export
Name[el]=Εξαγωγή σε απομακρυσμένη Piwigo
Name[en_GB]=Remote Piwigo Export
Name[es]=Exportar a un Piwigo remoto
Name[et]=Piwigo eksport
Name[eu]=Urruneko Piwigo-ra esportatzea
Name[fr]=Module externe pour l'exportation vers Piwigo
Name[ga]=Easpórtáil go Piwigo Cianda
Name[gl]=Exportación remota a Piwigo
Name[hu]=Távoli Piwigo exportálás
Name[is]=Samstilling við Piwigo myndasöfn
Name[it]=Esportazione remota a Piwigo
Name[km]=ការ​នាំ​ចេញ​ Piwigo ​ពី​ចម្ងាយ
Name[nb]=Piwigo-eksport til nettverket
Name[nl]=Piwigo-export op afstand
Name[pl]=Eksport do zdalnego Piwigo
Name[pt]=Exportação para um Piwigo Remoto
Name[pt_BR]=Exportar para Piwigo remoto
Name[ro]=Export către Piwigo
Name[ru]=Экспорт в Piwigo
Name[sl]=Izvoz v oddaljeno storitev Piwigo
Name[sv]=Fjärrexport till Piwigo
Name[th]=ส่งออกไปยังบริการ Piwigo ทางไกล
Name[uk]=Експорт до віддаленого ресурсу Piwigo
Name[x-test]=xxRemote Piwigo Exportxx
Name[zh_CN]=远程 Piwigo 导出
Name[zh_TW]=遠端 Piwigo 匯出
Comment=A tool to export images to a remote Piwigo
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Piwigo
Comment[bs]=Alat za izvoz slika na udaljeni Piwigo
Comment[ca]=Una eina per exportar imatges al servei remot Piwigo
Comment[ca@valencia]=Una eina per exportar imatges al servei remot Piwigo
Comment[cs]=;Nástroj pro export obrázků na vzdálené Piwigo
Comment[da]=Et værktøj til at eksportere billeder til en ekstern Piwigo
Comment[de]=Ein Werkzeug, um Bilder zu einer entfernten Piwigo-Installation zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη πινακοθήκη Piwigo
Comment[en_GB]=A tool to export images to a remote Piwigo
Comment[es]=Una herramienta para exportar imágenes a un Piwigo remoto
Comment[et]=Tööriist piltide eksportimiseks Piwigosse
Comment[eu]=Urruneko Piwigo-ra irudiak esportatzeko tresna
Comment[fr]=Outil pour l'exportation vers Piwigo
Comment[gl]=Unha ferramenta para exportar imaxes a un Piwigo remoto
Comment[hu]=Egy eszköz képek exportálásához egy távoli Piwigo-ba
Comment[is]=Verkfæri til að senda myndir í fjarlæg Piwigo myndasöfn
Comment[it]=Uno strumento per esportare immagini a un Piwigo remoto
Comment[km]=ឧបករណ៍​សម្រាប់​នាំ​ចេញ​រូបភាព​ទៅ​កាន់​ Piwigo ពី​ចម្ងាយ
Comment[nb]=Et verktøy for å eksportere bilder til en fjern Piwigo
Comment[nl]=Een hulpmiddel om afbeeldingen te exporteren naar Piwigo op afstand
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnego Piwigo
Comment[pt]=Uma ferramenta para exportar imagens para um Piwigo remoto
Comment[pt_BR]=Uma ferramenta para exportar imagens para um Piwigo remoto
Comment[ro]=O unealtă de exportat imagini către Piwigo
Comment[ru]=Инструмент для экспорта изображений в Piwigo
Comment[sl]=Orodje za izvoz slik v oddaljeno storitev Piwigo
Comment[sv]=Ett verktyg för att fjärrexportera bilder till Piwigo
Comment[th]=เครื่องมือส่งออกภาพต่าง ๆ ไปยังบริการ Piwigo ทางไกล
Comment[uk]=Інструмент для експорту зображення до віддаленого ресурсу Piwigo
Comment[x-test]=xxA tool to export images to a remote Piwigoxx
Comment[zh_CN]=一个将图像导出到远程 Piwigo 的工具
Comment[zh_TW]=匯出影像到遠端 Piwigo 的工具
Type=Service
Icon=piwigo
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_piwigoexport
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Frederic Coiffier, fcoiffie at gmail dot com
